""" configuration for the simulations"""

import multiprocessing as mp
from pathlib import Path

from bs_python_utils.bsutils import mkdir_if_needed

code_dir = Path.cwd()

# the path to the ChooSiow*.csv files
data_dir = code_dir.parent / "Data"

samples_dir = mkdir_if_needed(code_dir / "ChooSiow_samples")
results_dir = mkdir_if_needed(code_dir / "Results")

do_create_samples = False  # create the "small" and "large" samples in `samples_dir`

do_simuls = True
plot_simuls = True

model_name = "choo_siow_cupid"      # up to you
sample_size = "small"               # small or large

do_simuls_mde = True
do_simuls_poisson = True

# this is used to generate Figure 3
shrunk_model = True
# we shrink the Choo-Siow estimates by the following multiplicative integer
shrink_factor = 5 if shrunk_model else 1

renormalize_true_coeffs = True  # rescale all true coefficients to equal 1

n_sim = 1  # number of simulations

use_multiprocessing = False  # use multiprocessing for the simulations
# number of cpus to use for the simulations if multiprocessing;
#    by default we use all minus 2.
nb_cpus = mp.cpu_count() - 2

# degrees of polynomials for the basis functions
degrees = [(1, 0), (0, 1), (2, 0), (1, 1), (0, 2)]

n_households_cupid_popu = 13_274_041  # number of households in the Cupid population

#  if zero_guard is not 0, then for the MDE simulations,
#     we set the zero cells at the size of the smallest positive cell
#      divided by zero_guard.
zero_guard = 1

# this global variable is used to tick the number of simulations done
n_simulations_done = mp.Value("i", 0)
